@@ -8,9 +8,9 @@ class match(Task):
         self.pattern = pattern
 
     def process(self, inputs):
-        for t, c in inputs:
+        for t, c, m in inputs:
             if t.match(self.pattern):
-                yield t, c
+                yield t, c, m
 
 
 class exclude(Task):
@@ -20,6 +20,6 @@ class exclude(Task):
         self.pattern = pattern
 
     def process(self, inputs):
-        for t, c in inputs:
+        for t, c, m in inputs:
             if not t.match(self.pattern):
-                yield t, c
+                yield t, c, m
